@@ -161,6 +161,7 @@ class FormaPagamentoConfiguracao(models.Model):
     token_expiracao = models.DateTimeField(db_column="pagamento_configuracao_token_expiracao", null=True)
     assinatura = models.CharField(db_column="pagamento_configuracao_assinatura", max_length=128, null=True)
     codigo_autorizacao = models.CharField(db_column="pagamento_configuracao_codigo_autorizacao", max_length=128, null=True)
+    usar_antifraude = models.BooleanField(db_column='pagamento_configuracao_usar_antifraude', null=True, default=False)
     aplicacao = models.CharField(db_column="pagamento_configuracao_aplicacao_id", max_length=128, null=True, default=None)
     ativo = models.BooleanField(db_column="pagamento_configuracao_ativo", default=False)
     mostrar_parcelamento = models.BooleanField(db_column='pagamento_coonfiguracao_mostrar_parcelamento', default=False, null=False)
@@ -169,6 +170,7 @@ class FormaPagamentoConfiguracao(models.Model):
     desconto = models.BooleanField(db_column="pagamento_configuracao_desconto", default=False, null=False)
     desconto_tipo = models.CharField(db_column="pagamento_configuracao_desconto_tipo", max_length=32, default=TIPO_PORCENTAGEM)
     desconto_valor = models.DecimalField(db_column='pagamento_configuracao_desconto_valor', max_digits=16, decimal_places=2, null=True)
+    juros_valor = models.DecimalField(db_column='pagamento_configuracao_juros_valor', max_digits=16, decimal_places=6, null=True)
     email_comprovante = models.EmailField(db_column='pagamento_configuracao_email_comprovante', null=True)
     informacao_complementar = models.TextField(db_column='pagamento_configuracao_informacao_complementar', null=True)
     aplicar_no_total = models.BooleanField(db_column='pagamento_configuracao_desconto_aplicar_no_total', null=False, default=False)
