@@ -178,6 +178,28 @@ class PlanoAssinatura(models.Model):
         db_table = u"faturamento\".\"tb_plano_assinatura"
 
 
+class Tema(models.Model):
+
+    id = models.AutoField(db_column="tema_id", primary_key=True)
+    nome = models.TextField(db_column="tema_nome")
+    poweredby = models.TextField(db_column="tema_poweredby")
+    chamada = models.TextField(db_column="tema_chamada")
+    valor = models.DecimalField(db_column="tema_valor")
+
+    headtags = models.TextField(db_column="tema_headtags")
+    url_thumbnail = models.TextField(db_column="tema_url_thumbnail")
+    url_screenshots = models.TextField(db_column="tema_url_screenshots")
+    url_download = models.TextField(db_column="tema_url_download")
+    data_criacao = models.DateTimeField(db_column="tema_data_criacao", default=0)
+    data_modificacao = models.DateTimeField(db_column="tema_data_modificacao", auto_now=True)
+
+    colecao = models.ForeignKey("Colecao", db_column="colecao_id")
+
+    class Meta:
+        app_label = 'faturamento'
+        db_table = u"faturamento\".\"tb_tema"
+
+
 class Consumo(models.Model):
 
     id = models.AutoField(db_column="consumo_id", primary_key=True)
