@@ -184,6 +184,7 @@ class PedidoVendaFormaPagamento(models.Model):
     transacao_id = models.CharField(db_column="pedido_venda_pagamento_transacao_id", max_length=64, null=True)
     identificador_id = models.CharField(db_column="pedido_venda_pagamento_identificador_id", max_length=64, null=True)
     conteudo = models.TextField(db_column="pedido_venda_pagamento_conteudo", null=True)
+    conteudo_json = JSONField(db_column="pedido_venda_pagamento_conteudo_json", null=True)
     data_criacao = models.DateTimeField(db_column="pedido_venda_pagamento_data_criacao", auto_now_add=True)
     data_modificacao = models.DateTimeField(db_column="pedido_venda_pagamento_data_modificacao", auto_now=True)
     pagamento_externo = models.BooleanField(db_column="pedido_venda_pagamento_pagamento_externo", null=False, default=False)
@@ -248,7 +249,6 @@ class PedidoVenda(models.Model):
     # foi criado por algum serviço externo e depois importado na Loja Integerada
     # ou que ele foi criado na Loja Integrada e depois exportado para outro local.
     referencia = models.TextField(db_column='pedido_venda_referencia', null=True, default=None)
-    servico = models.ForeignKey("plataforma.Servico", related_name='pedidos', null=True, on_delete=models.SET_NULL)
 
     class Meta:
         db_table = u"pedido\".\"tb_pedido_venda"
